@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for GNU Prolog 1.4.2 (and later versions)
-%  Last updated on May 9, 2016
+%  Last updated on August 7, 2016
 %
 %  This file is part of Logtalk <http://logtalk.org/>  
 %  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
@@ -210,6 +210,7 @@ setup_call_cleanup(_, _, _) :-
 	'$lgt_prolog_feature'(modules, unsupported).
 :- endif.
 '$lgt_prolog_feature'(coinduction, unsupported).
+'$lgt_prolog_feature'(unicode, unsupported).
 
 
 
@@ -601,7 +602,11 @@ thread_peek_message(_, _) :- fail.
 thread_property(_, _) :- fail.
 thread_self(_) :- fail.
 thread_send_message(_, _) :- fail.
+thread_join(_, _) :- fail.
 with_mutex(_, _) :- fail.
+message_queue_create(_) :- fail.
+message_queue_destroy(_) :- fail.
+:- dynamic('$lgt_engine_term_queue_'/2).
 
 
 
